@@ -1,6 +1,8 @@
 #!/usr/bin/env Rscript
 
 library(testthat)
+library(tibble)
+library(dplyr)
 library(tidygeocoder)
 
 test_check("tidygeocoder")
